ct_leq_mp_mp

Function ct_leq_mp_mp 

pub fn ct_leq_mp_mp<T0: MpUIntCommon, T1: MpUIntCommon>(
    op0: &T0,
    op1: &T1,
) -> LimbChoice
Compare two multiprecision integers of specified endianess for <=.

Evaluates to true iff op0 is less or equal than op1 in value.

Arguments

  • op0 - The first operand as a multiprecision integer byte buffer.
  • op1 - The second operand as a multiprecision integer byte buffer.